base_req: Build a base request pointing at the running server

View source: R/server.R

base_reqR Documentation

Build a base request pointing at the running server

Description

Build a base request pointing at the running server

Usage

base_req(path)

Arguments

path

API path (e.g. "/fit").

Value

An httr2 request object.


rMIDAS2 documentation built on March 12, 2026, 9:07 a.m.