| ensure_server | R Documentation |
Starts the server if it is not already running. Called internally by every client function so users never have to manage the server manually.
ensure_server(...)
... |
Arguments forwarded to |
Invisibly returns the base URL of the running server.
## Not run:
ensure_server()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.