| install_backend | R Documentation |
Creates an isolated Python environment and installs the midasverse-midas-api
package (which pulls in midasverse-midas as a dependency).
install_backend(
method = c("pip", "conda", "uv"),
envname = "midas2_env",
package = "midasverse-midas-api"
)
method |
Character. One of |
envname |
Character. Name of the virtual environment to create
(default |
package |
Character. Package specifier to install
(default |
This is the only function in the package that uses reticulate, and
only for environment creation. It is never used at runtime.
No return value, called for side effects.
## Not run:
install_backend()
install_backend(method = "conda")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.